import{T as n,A as d}from"./TabPane.439993c1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4c8d1622-6ac6-4adb-8a38-ed4f01593b50",e._sentryDebugIdIdentifier="sentry-dbid-4c8d1622-6ac6-4adb-8a38-ed4f01593b50")}catch{}})();n.TabPane=d;n.install=function(e){return e.component(n.name,n),e.component(d.name,d),e};
//# sourceMappingURL=index.e3cd80f7.js.map
