import{d as b,ey as u,H as f,b as y,c as _,u as g}from"./registerWidgets.9fce82a0.js";import{a as w}from"./asyncComputed.a4b709a3.js";import"./gateway.6deb8468.js";import{M as n}from"./member.fd1df6db.js";import"./index.75e03e08.js";import{_ as I}from"./CrudView.vue_vue_type_script_setup_true_lang.ac5a77d6.js";import"./passwordlessManager.eda842b8.js";import"./pubsub.025cc397.js";import"./storage.ae287dfa.js";import"./activeRecord.872f4269.js";import"./index.2c964e80.js";import"./Title.26974edb.js";import"./Form.413853c0.js";import"./icons.1992e13b.js";import"./index.eed9c711.js";import"./index.30c35b37.js";import"./index.c9f7f8f0.js";import"./index.db5cf0e6.js";import"./index.e8158c16.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="de2bec4d-afd4-4db3-861b-267a5ce89ee6",e._sentryDebugIdIdentifier="sentry-dbid-de2bec4d-afd4-4db3-861b-267a5ce89ee6")}catch{}})();const F=b({__name:"Members",setup(e){const a=u().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(a,t.email),p()},{loading:d,result:l,refetch:p}=w(()=>n.list(a)),c=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=l.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?r:[]}});return(t,r)=>(y(),_(I,{"entity-name":"members",loading:g(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.e51fe00e.js.map
