import{d as r,r as i,o as f,eN as d,b as l,er as u,eA as p,eL as y}from"./registerWidgets.9fce82a0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="412c440c-c83e-44a7-82e8-dffcf46f2cf2",e._sentryDebugIdIdentifier="sentry-dbid-412c440c-c83e-44a7-82e8-dffcf46f2cf2")}catch{}})();const b=r({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=i(null);return f(()=>{s.value&&o.action.setElement(s.value),d.addAction(o.action)}),(a,t)=>(l(),u("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=c=>n("click")),onKeydown:t[1]||(t[1]=y(c=>n("click"),["enter"]))},p(a.displayName),545))}});export{b as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.f47e89b8.js.map
