import{v as t,b as s,er as r}from"./registerWidgets.9fce82a0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cf042d65-0ec6-447a-969a-90b707cfe254",e._sentryDebugIdIdentifier="sentry-dbid-cf042d65-0ec6-447a-969a-90b707cfe254")}catch{}})();const o={},a={class:"organization-settings"};function c(e,n){return s(),r("div",a,"Organization settings")}const f=t(o,[["render",c]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.80ac3ec4.js.map
