import{d as b,ex as g,ey as v,r as k,b as r,c as s,w as a,u as e,f as l,eu as i}from"./registerWidgets.9fce82a0.js";import{S as h,L as w}from"./SmartConsole.6ed7ad1c.js";import{a as x}from"./asyncComputed.a4b709a3.js";import{H as B}from"./hooks.31ddb50a.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.5580f63b.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.41ad9626.js";import{B as I}from"./BaseLayout.ec0601c1.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.51304edf.js";import{c as D}from"./index.b9dfa5e6.js";import{A as _,T as R}from"./TabPane.439993c1.js";import"./forms.f9e60a69.js";import"./activeRecord.872f4269.js";import"./pubsub.025cc397.js";import"./dashes.ea544587.js";import"./index.9df32b45.js";import"./jobs.ffce9a38.js";import"./workspaces.7ad2f8ea.js";import"./icons.1992e13b.js";import"./Title.26974edb.js";import"./index.c9f7f8f0.js";import"./uuid.f77225ce.js";import"./storage.ae287dfa.js";import"./ant-design.cd2520f8.js";import"./index.3995bfa0.js";import"./index.e8158c16.js";import"./index.db5cf0e6.js";import"./index.eed9c711.js";import"./Form.413853c0.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="ea583025-49a6-4122-93d4-77990d904b9b",n._sentryDebugIdIdentifier="sentry-dbid-ea583025-49a6-4122-93d4-77990d904b9b")}catch{}})();const ie=b({__name:"HookEditor",setup(n){const m=g(),p=v(),c=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(p.params.hookPath)),f=w.create();return($,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[l(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[l(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:c,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=c.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ie as default};
//# sourceMappingURL=HookEditor.bf896aa7.js.map
