import{v as r,a,b as i,c,g as p,h as d,_,i as u,l,T as h,P as b,C as f,M as g,s as y,j as m,k as s,m as v,n as w,p as k}from"./registerWidgets.9fce82a0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e69ac316-06cb-41cb-bd15-a14bf3c73ee9",e._sentryDebugIdIdentifier="sentry-dbid-e69ac316-06cb-41cb-bd15-a14bf3c73ee9")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.6c6480e1.js"),["assets/Player.6c6480e1.js","assets/index.9df32b45.js","assets/registerWidgets.9fce82a0.js","assets/registerWidgets.8ce475af.css","assets/uuid.f77225ce.js","assets/broker.640b7bc7.js","assets/passwordlessManager.eda842b8.js","assets/pubsub.025cc397.js","assets/storage.ae287dfa.js","assets/Passwordless.0badc2f2.js","assets/CircularLoading.45bdfef7.js","assets/CircularLoading.f81b57b4.css","assets/icons.1992e13b.js","assets/Passwordless.38735f5c.css","assets/executeJs.0cb26839.js","assets/PlayerNavbar.80abf434.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.a44e7d48.js","assets/Steps.998aa76d.css","assets/Modal.3e57b15b.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.28239fa9.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.f47e89b8.js","assets/broker.fcc295cc.css","assets/DashPlayer.79123606.js","assets/geometryUtils.22d60cf9.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.a4b709a3.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});h.init(),D.init(),e.use(o),e.use(b),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",g),e.component("Message",y),m(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.1bdcf102.js.map
