import{u as s}from"./icons.1992e13b.js";import{d as c,a as r,b as i,er as d,f,u as _,b0 as l,v as u}from"./registerWidgets.9fce82a0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="196b2763-1ff4-4c19-9ca7-6f43b8fd6c6a",e._sentryDebugIdIdentifier="sentry-dbid-196b2763-1ff4-4c19-9ca7-6f43b8fd6c6a")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[f(a,{class:"icon",path:_(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.b000685b.js.map
