import{P as r}from"./Passwordless.0badc2f2.js";import{d as a,ex as d,b as i,er as f,f as s,w as _,v as c}from"./registerWidgets.9fce82a0.js";import{M as m}from"./member.fd1df6db.js";import{W as p}from"./WidgetsFrame.28239fa9.js";import"./CircularLoading.45bdfef7.js";import"./icons.1992e13b.js";import"./passwordlessManager.eda842b8.js";import"./pubsub.025cc397.js";import"./storage.ae287dfa.js";import"./gateway.6deb8468.js";import"./activeRecord.872f4269.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="163d947d-2fe2-4bbb-baee-f6a17f05a293",e._sentryDebugIdIdentifier="sentry-dbid-163d947d-2fe2-4bbb-baee-f6a17f05a293")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=d();async function t(n){await m.login(),o.push({name:"home"})}return(n,b)=>(i(),f("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const B=c(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.7b1cf12c.js.map
