import{d as g,ex as v,ey as k,r as _,b as r,c as a,w as s,u as e,f as l,eu as i}from"./registerWidgets.9fce82a0.js";import{S as j,L as w}from"./SmartConsole.6ed7ad1c.js";import{a as I}from"./asyncComputed.a4b709a3.js";import{J as x}from"./jobs.ffce9a38.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.5580f63b.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.41ad9626.js";import{B as S}from"./BaseLayout.ec0601c1.js";import{_ as T,a as D}from"./JobSettings.vue_vue_type_script_setup_true_lang.8d224336.js";import{c as R}from"./index.b9dfa5e6.js";import{A as b,T as $}from"./TabPane.439993c1.js";import"./forms.f9e60a69.js";import"./activeRecord.872f4269.js";import"./pubsub.025cc397.js";import"./dashes.ea544587.js";import"./index.9df32b45.js";import"./hooks.31ddb50a.js";import"./workspaces.7ad2f8ea.js";import"./icons.1992e13b.js";import"./Title.26974edb.js";import"./index.c9f7f8f0.js";import"./uuid.f77225ce.js";import"./storage.ae287dfa.js";import"./ant-design.cd2520f8.js";import"./dayjs.89aecc81.js";import"./index.eed9c711.js";import"./Form.413853c0.js";import"./index.e8158c16.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="29465fe8-da10-43a3-ae54-0a5774aa6cf0",n._sentryDebugIdIdentifier="sentry-dbid-29465fe8-da10-43a3-ae54-0a5774aa6cf0")}catch{}})();const ne=g({__name:"JobEditor",setup(n){const m=v(),f=k(),c=_(null),o=_("test");function y(){m.push({name:"jobs"})}const{result:t}=I(()=>x.get(f.params.jobId)),p=w.create();return(A,d)=>(r(),a(S,null,{navbar:s(()=>[e(t)?(r(),a(e(R),{key:0,title:e(t).title,onBack:y},{footer:s(()=>[l(e($),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:s(()=>[l(e(b),{key:"test",tab:"Test"}),l(e(b),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[l(C),o.value==="settings"?(r(),a(B,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(T,{key:0,ref_key:"tester",ref:c,job:e(t),"log-service":e(p)},null,8,["job","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),a(D,{key:1,job:e(t)},null,8,["job"])):i("",!0)]),footer:s(()=>{var u;return[e(t)&&o.value==="test"?(r(),a(j,{key:0,runtime:"forms","log-service":e(p),onRestart:(u=c.value)==null?void 0:u.test},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=JobEditor.98a3f2dc.js.map
